@@ -19,7 +19,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2011 Alexandre Cassen, <acassen@linux-vs.org>
+ * Copyright (C) 2001-2012 Alexandre Cassen, <acassen@gmail.com>
  */
 
 #include "layer4.h"
@@ -81,11 +81,11 @@ tcp_socket_state(int fd, thread_t * thread, uint32_t addr_ip, uint16_t addr_port
 	int status;
 	socklen_t slen;
 	int ret = 0;
-	TIMEVAL timer_min;
+	timeval_t timer_min;
 
 	/* Handle connection timeout */
 	if (thread->type == THREAD_WRITE_TIMEOUT) {
-		DBG("TCP connection timeout to [%s:%d].\n",
+		DBG("TCP connection timeout to [%s]:%d.\n",
 		    inet_ntop2(addr_ip), ntohs(addr_port));
 		close(thread->u.fd);
 		return connect_timeout;
@@ -99,7 +99,7 @@ tcp_socket_state(int fd, thread_t * thread, uint32_t addr_ip, uint16_t addr_port
 
 	/* Connection failed !!! */
 	if (ret) {
-		DBG("TCP connection failed to [%s:%d].\n",
+		DBG("TCP connection failed to [%s]:%d.\n",
 		    inet_ntop2(addr_ip), ntohs(addr_port));
 		close(thread->u.fd);
 		return connect_error;
@@ -111,12 +111,12 @@ tcp_socket_state(int fd, thread_t * thread, uint32_t addr_ip, uint16_t addr_port
 	 * Recompute the write timeout (or pending connection).
 	 */
 	if (status != 0) {
-		DBG("TCP connection to [%s:%d] still IN_PROGRESS.\n",
+		DBG("TCP connection to [%s]:%d still IN_PROGRESS.\n",
 		    inet_ntop2(addr_ip), ntohs(addr_port));
 
 		timer_min = timer_sub_now(thread->sands);
 		thread_add_write(thread->master, func, THREAD_ARG(thread)
-				 , thread->u.fd, TIMER_LONG(timer_min));
+				 , thread->u.fd, timer_long(timer_min));
 		return connect_in_progress;
 	}
 
@@ -160,14 +160,14 @@ tcp_check_thread(thread_t * thread)
 			     tcp_check_thread);
 	switch (sock_obj->status) {
 	case connect_error:
-		DBG("Error connecting server [%s:%d].\n",
+		DBG("Error connecting server [%s]:%d.\n",
 		    inet_ntop2(req->addr_ip), ntohs(req->addr_port));
 		thread_add_terminate_event(thread->master);
 		return -1;
 		break;
 
 	case connect_timeout:
-		DBG("Timeout connecting server [%s:%d].\n",
+		DBG("Timeout connecting server [%s]:%d.\n",
 		    inet_ntop2(req->addr_ip), ntohs(req->addr_port));
 		thread_add_terminate_event(thread->master);
 		return -1;
@@ -185,7 +185,7 @@ tcp_check_thread(thread_t * thread)
 				thread_add_event(thread->master,
 						 http_request_thread, sock_obj, 0);
 			} else {
-				DBG("Connection trouble to: [%s:%d].\n",
+				DBG("Connection trouble to: [%s]:%d.\n",
 				    inet_ntop2(req->addr_ip),
 				    ntohs(req->addr_port));
 				if (req->ssl)
