@@ -18,7 +18,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2011 Alexandre Cassen, <acassen@linux-vs.org>
+ * Copyright (C) 2001-2012 Alexandre Cassen, <acassen@gmail.com>
  */
 
 #include <openssl/err.h>
@@ -97,15 +97,17 @@ alloc_http_get(char *proto)
 	    (!strcmp(proto, "HTTP_GET")) ? PROTO_HTTP : PROTO_SSL;
 	http_get_chk->url = alloc_list(free_url, dump_url);
 	http_get_chk->nb_get_retry = 1;
+	http_get_chk->connection_to = 5 * TIMER_HZ;
+	http_get_chk->delay_before_retry = 3 * TIMER_HZ;
 
 	return http_get_chk;
 }
 
 void
-http_get_handler(vector strvec)
+http_get_handler(vector_t *strvec)
 {
 	http_checker_t *http_get_chk;
-	char *str = VECTOR_SLOT(strvec, 0);
+	char *str = vector_slot(strvec, 0);
 
 	/* queue new checker */
 	http_get_chk = alloc_http_get(str);
@@ -115,42 +117,44 @@ http_get_handler(vector strvec)
 }
 
 void
-connect_p_handler(vector strvec)
+connect_p_handler(vector_t *strvec)
 {
 	http_checker_t *http_get_chk = CHECKER_GET();
 	checker_set_dst_port(&http_get_chk->dst, htons(CHECKER_VALUE_INT(strvec)));
 }
 
 void
-bindto_handler(vector strvec)
+bindto_handler(vector_t *strvec)
 {
 	http_checker_t *http_get_chk = CHECKER_GET();
-	inet_stosockaddr(VECTOR_SLOT(strvec, 1), 0, &http_get_chk->bindto);
+	inet_stosockaddr(vector_slot(strvec, 1), 0, &http_get_chk->bindto);
 }
 
 void
-connect_to_handler(vector strvec)
+connect_to_handler(vector_t *strvec)
 {
 	http_checker_t *http_get_chk = CHECKER_GET();
 	http_get_chk->connection_to = CHECKER_VALUE_INT(strvec) * TIMER_HZ;
+	if (http_get_chk->connection_to < TIMER_HZ)
+		http_get_chk->connection_to = TIMER_HZ;
 }
 
 void
-nb_get_retry_handler(vector strvec)
+nb_get_retry_handler(vector_t *strvec)
 {
 	http_checker_t *http_get_chk = CHECKER_GET();
 	http_get_chk->nb_get_retry = CHECKER_VALUE_INT(strvec);
 }
 
 void
-delay_before_retry_handler(vector strvec)
+delay_before_retry_handler(vector_t *strvec)
 {
 	http_checker_t *http_get_chk = CHECKER_GET();
 	http_get_chk->delay_before_retry = CHECKER_VALUE_INT(strvec) * TIMER_HZ;
 }
 
 void
-url_handler(vector strvec)
+url_handler(vector_t *strvec)
 {
 	http_checker_t *http_get_chk = CHECKER_GET();
 	url_t *new;
@@ -162,7 +166,7 @@ url_handler(vector strvec)
 }
 
 void
-path_handler(vector strvec)
+path_handler(vector_t *strvec)
 {
 	http_checker_t *http_get_chk = CHECKER_GET();
 	url_t *url = LIST_TAIL_DATA(http_get_chk->url);
@@ -171,7 +175,7 @@ path_handler(vector strvec)
 }
 
 void
-digest_handler(vector strvec)
+digest_handler(vector_t *strvec)
 {
 	http_checker_t *http_get_chk = CHECKER_GET();
 	url_t *url = LIST_TAIL_DATA(http_get_chk->url);
@@ -180,7 +184,7 @@ digest_handler(vector strvec)
 }
 
 void
-status_code_handler(vector strvec)
+status_code_handler(vector_t *strvec)
 {
 	http_checker_t *http_get_chk = CHECKER_GET();
 	url_t *url = LIST_TAIL_DATA(http_get_chk->url);
@@ -746,7 +750,7 @@ http_check_thread(thread_t * thread)
 				new_req = 0;
 
 			if (http_get_check->proto == PROTO_SSL) {
-				timeout = TIMER_LONG(thread->sands)-TIMER_LONG(time_now);
+				timeout = timer_long(thread->sands) - timer_long(time_now);
 				if (thread->type != THREAD_WRITE_TIMEOUT &&
 				    thread->type != THREAD_READ_TIMEOUT)
 					ret = ssl_connect(thread, new_req);
@@ -793,7 +797,7 @@ http_check_thread(thread_t * thread)
 						 thread->u.fd,
 						 http_get_check->connection_to);
 			} else {
-				DBG(LOG_INFO, "Connection trouble to: [%s]:%d."
+				DBG("Connection trouble to: [%s]:%d."
 					    , inet_sockaddrtos(&http_get_check->dst)
 					    , ntohs(inet_sockaddrport(&http_get_check->dst)));
 #ifdef _DEBUG_
@@ -871,19 +875,23 @@ http_connect_thread(thread_t * thread)
 
 	/* Create the socket */
 	if ((fd = socket(http_get_check->dst.ss_family, SOCK_STREAM, IPPROTO_TCP)) == -1) {
-		DBG("WEB connection fail to create socket.");
+		log_message(LOG_INFO, "WEB connection fail to create socket. Rescheduling.");
+		thread_add_timer(thread->master, http_connect_thread, checker,
+				checker->vs->delay_loop);
+ 
 		return 0;
 	}
 
 	status = tcp_bind_connect(fd, &http_get_check->dst, &http_get_check->bindto);
-	if (status == connect_error) {
-		thread_add_timer(thread->master, http_connect_thread, checker,
-				 checker->vs->delay_loop);
-		return 0;
-	}
 
 	/* handle tcp connection status & register check worker thread */
-	tcp_connection_state(fd, status, thread, http_check_thread,
-			     http_get_check->connection_to);
+	if(tcp_connection_state(fd, status, thread, http_check_thread,
+			http_get_check->connection_to)) {
+		close(fd);
+		log_message(LOG_INFO, "WEB socket bind failed. Rescheduling");
+		thread_add_timer(thread->master, http_connect_thread, checker,
+				checker->vs->delay_loop);
+	}
+
 	return 0;
 }
