@@ -17,7 +17,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2011 Alexandre Cassen, <acassen@linux-vs.org>
+ * Copyright (C) 2001-2012 Alexandre Cassen, <acassen@gmail.com>
  */
 
 #ifndef _CHECK_API_H
@@ -47,7 +47,7 @@ extern list checkers_queue;
 #define CHECKER_ARG(X) ((X)->data)
 #define CHECKER_DATA(X) (((checker_t *)X)->data)
 #define CHECKER_GET() (CHECKER_DATA(LIST_TAIL_DATA(checkers_queue)))
-#define CHECKER_VALUE_INT(X) (atoi(VECTOR_SLOT(X,1)))
+#define CHECKER_VALUE_INT(X) (atoi(vector_slot(X,1)))
 #define CHECKER_VALUE_STRING(X) (set_value(X))
 #define CHECKER_VHOST(C) (VHOST((C)->vs))
 #define CHECKER_ENABLED(C) ((C)->enabled)
