@@ -17,7 +17,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2011 Alexandre Cassen, <acassen@linux-vs.org>
+ * Copyright (C) 2001-2012 Alexandre Cassen, <acassen@gmail.com>
  */
 
 #ifndef _CHECK_DATA_H
@@ -55,8 +55,7 @@ typedef unsigned int checker_id_t;
 #define KEEPALIVED_DEFAULT_DELAY	(60 * TIMER_HZ) 
 
 /* SSL specific data */
-typedef struct _ssl_data SSL_DATA;
-typedef struct _ssl_data {
+typedef struct ssl_data {
 	int enable;
 	int strong_check;
 	SSL_CTX *ctx;
@@ -65,7 +64,7 @@ typedef struct _ssl_data {
 	char *cafile;
 	char *certfile;
 	char *keyfile;
-} ssl_data;
+} ssl_data_t;
 
 /* Real Server definition */
 typedef struct _real_server {
@@ -84,6 +83,13 @@ typedef struct _real_server {
 	int alive;
 	list failed_checkers;	/* List of failed checkers */
 	int set;		/* in the IPVS table */
+#if defined(_WITH_SNMP_) && defined(_KRNL_2_6_) && defined(_WITH_LVS_)
+	/* Statistics */
+	uint32_t activeconns;  /* active connections */
+	uint32_t inactconns;   /* inactive connections */
+	uint32_t persistconns; /* persistent connections */
+	struct ip_vs_stats_user stats;
+#endif
 } real_server;
 
 /* Virtual Server group definition */
@@ -126,11 +132,16 @@ typedef struct _virtual_server {
 
 	long unsigned hysteresis;	/* up/down events "lag" WRT quorum. */
 	unsigned quorum_state;		/* Reflects result of the last transition done. */
+#if defined(_WITH_SNMP_) && defined(_KRNL_2_6_) && defined(_WITH_LVS_)
+	/* Statistics */
+	time_t lastupdated;
+	struct ip_vs_stats_user stats;
+#endif
 } virtual_server;
 
 /* Configuration data root */
 typedef struct _check_conf_data {
-	SSL_DATA *ssl;
+	ssl_data_t *ssl;
 	list vs_group;
 	list vs;
 } check_conf_data;
@@ -163,10 +174,11 @@ static inline int sockstorage_equal(const struct sockaddr_storage *s1,
 		struct sockaddr_in *a1 = (struct sockaddr_in *) s1;
 		struct sockaddr_in *a2 = (struct sockaddr_in *) s2;
 
-		if ((a1->sin_addr.s_addr == a1->sin_addr.s_addr) &&
+		if ((a1->sin_addr.s_addr == a2->sin_addr.s_addr) &&
 		    (a1->sin_port == a2->sin_port))
 			return 1;
-	}
+	} else if (s1->ss_family == AF_UNSPEC)
+		return 1;
 
 	return 0;
 }
@@ -220,10 +232,10 @@ extern check_conf_data *check_data;
 extern check_conf_data *old_check_data;
 
 /* prototypes */
-extern SSL_DATA *alloc_ssl(void);
+extern ssl_data_t *alloc_ssl(void);
 extern void free_ssl(void);
 extern void alloc_vsg(char *);
-extern void alloc_vsg_entry(vector);
+extern void alloc_vsg_entry(vector_t *);
 extern void alloc_vs(char *, char *);
 extern void alloc_rs(char *, char *);
 extern void alloc_ssvr(char *, char *);
