@@ -17,7 +17,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2011 Alexandre Cassen, <acassen@linux-vs.org>
+ * Copyright (C) 2001-2012 Alexandre Cassen, <acassen@gmail.com>
  */
 
 #ifndef _VRRP_DATA_H
@@ -65,16 +65,16 @@ extern vrrp_conf_data *old_vrrp_data;
 extern char *vrrp_buffer;
 
 /* prototypes */
-extern void alloc_saddress(vector);
-extern void alloc_sroute(vector);
+extern void alloc_saddress(vector_t *);
+extern void alloc_sroute(vector_t *);
 extern void alloc_vrrp_sync_group(char *);
 extern void alloc_vrrp(char *);
-extern void alloc_vrrp_track(vector);
+extern void alloc_vrrp_track(vector_t *);
 extern void alloc_vrrp_script(char *);
-extern void alloc_vrrp_track_script(vector);
-extern void alloc_vrrp_vip(vector);
-extern void alloc_vrrp_evip(vector);
-extern void alloc_vrrp_vroute(vector);
+extern void alloc_vrrp_track_script(vector_t *);
+extern void alloc_vrrp_vip(vector_t *);
+extern void alloc_vrrp_evip(vector_t *);
+extern void alloc_vrrp_vroute(vector_t *);
 extern void alloc_vrrp_buffer(void);
 extern void free_vrrp_buffer(void);
 extern vrrp_conf_data *alloc_vrrp_data(void);
