@@ -20,7 +20,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2011 Alexandre Cassen, <acassen@linux-vs.org>
+ * Copyright (C) 2001-2012 Alexandre Cassen, <acassen@gmail.com>
  */
 
 /* local include */
@@ -35,6 +35,10 @@
 #include "vrrp_data.h"
 #include "vrrp_sync.h"
 #include "vrrp_index.h"
+#include "vrrp_vmac.h"
+#ifdef _WITH_SNMP_
+#include "vrrp_snmp.h"
+#endif
 #include "memory.h"
 #include "list.h"
 #include "logger.h"
@@ -233,8 +237,8 @@ vrrp_in_chk(vrrp_rt * vrrp, char *buffer)
 		ihl = ip->ihl << 2;
 
 		if (vrrp->auth_type == VRRP_AUTH_AH) {
-			ah = (ipsec_ah *) (buffer + sizeof (struct iphdr));
-			hd = (vrrp_pkt *) (buffer + ihl + vrrp_ipsecah_len());
+			ah = (ipsec_ah *) (buffer + ihl);
+			hd = (vrrp_pkt *) (ah + vrrp_ipsecah_len());
 		} else {
 			hd = (vrrp_pkt *) (buffer + ihl);
 		}
@@ -330,7 +334,7 @@ vrrp_in_chk(vrrp_rt * vrrp, char *buffer)
 	 */
 	if (vrrp->auth_type != hd->auth_type) {
 		log_message(LOG_INFO, "receive a %d auth, expecting %d!",
-		       vrrp->auth_type, hd->auth_type);
+		       hd->auth_type, vrrp->auth_type);
 		return VRRP_PACKET_KO;
 	}
 
@@ -369,7 +373,8 @@ vrrp_build_ip(vrrp_rt * vrrp, char *buffer, int buflen)
 
 	ip->ihl = 5;
 	ip->version = 4;
-	ip->tos = 0;
+	/* set tos to internet network control */
+	ip->tos = 0xc0;
 	ip->tot_len = ip->ihl * 4 + vrrp_hd_len(vrrp);
 	ip->tot_len = htons(ip->tot_len);
 	ip->id = htons(++vrrp->ip_id);
@@ -726,6 +731,10 @@ vrrp_state_become_master(vrrp_rt * vrrp)
 	/* Check if notify is needed */
 	notify_instance_exec(vrrp, VRRP_STATE_MAST);
 
+#ifdef _WITH_SNMP_
+	vrrp_snmp_instance_trap(vrrp);
+#endif
+
 #ifdef _HAVE_IPVS_SYNCD_
 	/* Check if sync daemon handling is needed */
 	if (vrrp->lvs_syncd_if)
@@ -740,6 +749,8 @@ vrrp_state_goto_master(vrrp_rt * vrrp)
 	 * Send an advertisement. To force a new master
 	 * election.
 	 */
+        if (vrrp->sync && !vrrp_sync_goto_master(vrrp))
+	      return;
 	vrrp_send_adv(vrrp, vrrp->effective_priority);
 
 	vrrp->state = VRRP_STATE_MAST;
@@ -751,6 +762,13 @@ vrrp_state_goto_master(vrrp_rt * vrrp)
 void
 vrrp_restore_interface(vrrp_rt * vrrp, int advF)
 {
+        /* if we stop vrrp, warn the other routers to speed up the recovery */
+	if (advF) {
+	        syslog(LOG_INFO, "VRRP_Instance(%s) sending 0 priority",
+		       vrrp->iname);
+		vrrp_send_adv(vrrp, VRRP_PRIO_STOP);
+	}
+
 	/* remove virtual routes */
 	if (!LIST_ISEMPTY(vrrp->vroutes))
 		vrrp_handle_iproutes(vrrp, IPROUTE_DEL);
@@ -771,10 +789,6 @@ vrrp_restore_interface(vrrp_rt * vrrp, int advF)
 		vrrp->vipset = 0;
 	}
 
-
-	/* if we stop vrrp, warn the other routers to speed up the recovery */
-	if (advF)
-		vrrp_send_adv(vrrp, VRRP_PRIO_STOP);
 }
 
 void
@@ -795,12 +809,18 @@ vrrp_state_leave_master(vrrp_rt * vrrp)
 		vrrp_restore_interface(vrrp, 0);
 		vrrp->state = vrrp->wantstate;
 		notify_instance_exec(vrrp, VRRP_STATE_BACK);
+#ifdef _WITH_SNMP_
+		vrrp_snmp_instance_trap(vrrp);
+#endif
 		break;
 	case VRRP_STATE_GOTO_FAULT:
 		log_message(LOG_INFO, "VRRP_Instance(%s) Entering FAULT STATE", vrrp->iname);
 		vrrp_restore_interface(vrrp, 0);
 		vrrp->state = VRRP_STATE_FAULT;
 		notify_instance_exec(vrrp, VRRP_STATE_FAULT);
+#ifdef _WITH_SNMP_
+		vrrp_snmp_instance_trap(vrrp);
+#endif
 		break;
 	}
 
@@ -998,6 +1018,7 @@ open_vrrp_send_socket(sa_family_t family, int proto, int idx)
 		if_setsockopt_hdrincl(&fd);
 		if_setsockopt_bindtodevice(&fd, ifp);
 		if_setsockopt_mcast_loop(family, &fd);
+		if_setsockopt_priority(&fd);
 		if (fd < 0)
 			return -1;
 	} else if (family == AF_INET6) {
@@ -1005,6 +1026,7 @@ open_vrrp_send_socket(sa_family_t family, int proto, int idx)
 		if_setsockopt_mcast_hops(family, &fd);
 		if_setsockopt_mcast_if(family, &fd, ifp);
 		if_setsockopt_mcast_loop(family, &fd);
+		if_setsockopt_priority(&fd);
 		if (fd < 0)
 			return -1;
 	} else {
@@ -1086,10 +1108,14 @@ shutdown_vrrp_instances(void)
 	for (e = LIST_HEAD(l); e; ELEMENT_NEXT(e)) {
 		vrrp = ELEMENT_DATA(e);
 
-		/* remove VIPs */
+		/* Remove VIPs/VROUTEs */
 		if (vrrp->state == VRRP_STATE_MAST)
 			vrrp_restore_interface(vrrp, 1);
 
+		/* Remove VMAC */
+		if (vrrp->vmac)
+			netlink_link_del_vmac(vrrp);
+
 		/* Run stop script */
 		if (vrrp->script_stop)
 			notify_exec(vrrp->script_stop);
@@ -1196,7 +1222,8 @@ reset_vrrp_state(vrrp_rt * old_vrrp)
 	vrrp->state = old_vrrp->state;
 	vrrp->init_state = old_vrrp->state;
 	vrrp->wantstate = old_vrrp->state;
-	vrrp->effective_priority = old_vrrp->effective_priority;
+	if (!old_vrrp->sync)
+		vrrp->effective_priority = old_vrrp->effective_priority;
 	memcpy(vrrp->ipsecah_counter, old_vrrp->ipsecah_counter, sizeof(seq_counter));
 
 #ifdef _HAVE_IPVS_SYNCD_
@@ -1237,13 +1264,19 @@ clear_diff_vrrp(void)
 
 	for (e = LIST_HEAD(l); e; ELEMENT_NEXT(e)) {
 		vrrp = ELEMENT_DATA(e);
+		vrrp_rt *new_vrrp;
 
 		/*
 		 * Try to find this vrrp into the new conf data
 		 * reloaded.
 		 */
-		if (!vrrp_exist(vrrp)) {
-			vrrp_restore_interface(vrrp, 0);
+		new_vrrp = vrrp_exist(vrrp);
+		if (!new_vrrp) {
+			vrrp_restore_interface(vrrp, 1);
+
+			/* Remove VMAC if one was created */
+			if (vrrp->vmac) 
+				netlink_link_del_vmac(vrrp);
 		} else {
 			/*
 			 * If this vrrp instance exist in new
@@ -1255,6 +1288,14 @@ clear_diff_vrrp(void)
 			/* virtual routes diff */
 			clear_diff_vrrp_vroutes(vrrp);
 
+			/* 
+			 * Remove VMAC if it existed in old vrrp instance,
+			 * but not the new one.
+			 */
+			if (vrrp->vmac && !new_vrrp->vmac) {
+				netlink_link_del_vmac(vrrp);
+			}
+
 			/* reset the state */
 			reset_vrrp_state(vrrp);
 		}
