@@ -17,7 +17,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2011 Alexandre Cassen, <acassen@linux-vs.org>
+ * Copyright (C) 2001-2012 Alexandre Cassen, <acassen@linux-vs.org>
  */
 
 #ifndef _PARSER_H
@@ -40,11 +40,11 @@
 #define MAXBUF	1024
 
 /* ketword definition */
-struct keyword {
+typedef struct _keyword {
 	char *string;
-	void (*handler) (vector);
-	vector sub;
-};
+	void (*handler) (vector_t *);
+	vector_t *sub;
+} keyword_t;
 
 /* Reloading helpers */
 #define SET_RELOAD      (reload = 1)
@@ -52,25 +52,25 @@ struct keyword {
 #define RELOAD_DELAY    5
 
 /* global vars exported */
-extern vector keywords;
+extern vector_t *keywords;
 extern FILE *current_stream;
 extern int reload;
 
 /* Prototypes */
-extern void keyword_alloc(vector keywords_vec, char *string, void (*handler) (vector));
-extern void keyword_alloc_sub(vector keywords_vec, char *string, void (*handler) (vector));
-extern void install_keyword_root(char *string, void (*handler) (vector));
+extern void keyword_alloc(vector_t *, char *, void (*handler) (vector_t *));
+extern void keyword_alloc_sub(vector_t *, char *, void (*handler) (vector_t *));
+extern void install_keyword_root(char *, void (*handler) (vector_t *));
 extern void install_sublevel(void);
 extern void install_sublevel_end(void);
-extern void install_keyword(char *string, void (*handler) (vector));
-extern void dump_keywords(vector keydump, int level);
-extern void free_keywords(vector keywords_vec);
-extern vector alloc_strvec(char *string);
-extern int read_line(char *buf, int size);
-extern vector read_value_block(void);
-extern void alloc_value_block(vector strvec, void (*alloc_func) (vector));
-extern void *set_value(vector strvec);
-extern void process_stream(vector keywords_vec);
-extern void init_data(char *conf_file, vector (*init_keywords) (void));
+extern void install_keyword(char *, void (*handler) (vector_t *));
+extern void dump_keywords(vector_t *, int);
+extern void free_keywords(vector_t *);
+extern vector_t *alloc_strvec(char *);
+extern int read_line(char *, int);
+extern vector_t *read_value_block(void);
+extern void alloc_value_block(vector_t *, void (*alloc_func) (vector_t *));
+extern void *set_value(vector_t *);
+extern void process_stream(vector_t *);
+extern void init_data(char *, vector_t * (*init_keywords) (void));
 
 #endif
